.location_area{
    padding: 0 50px;
    position: relative;
    #map{
        height: 800px !important;
        @media #{$tablet_device} {
            height: 600px;
        }
    }
    .location_info{
        display: inline-block;
        position: absolute;
        left: 50%;
        bottom: 0;
        z-index: 9;
        // transform: translateX(-50%);
        @include transform(translateX(-50%));
        @media #{$mobile_device}{
        @include transform(translateX(0%));
        left: 0%;
        position: relative;

        }
        .location_inner{
            background: #fff;
            width: 616px;
            max-width: 616px;
            // padding: 37px 60px 50px 60px;
            padding: 54px 60px 54px 60px;
            @media #{$mobile_device} {
                padding: 20px;
                width: 100%;
                bottom: 0;
            }
            .location_top{
                margin-bottom: 42px;
            }
            h3{
                font-size: 36px;
                font-weight: 400;
                color: #C78665;
            }
            p{
                color: #727272;
                font-size: 16px;
                font-family: $font1;
                line-height: 28px;
                margin-bottom: 0;
                font-weight: 400;
                span{
                    color: #C78665;
                }
            }
            .address_info{
                @media #{$mobile_device} {
                    display: block !important;
                }
                .single_address{
                    h4{
                        color: #C78665;
                        font-size: 16px;
                        font-family: $font1;
                        font-weight: 600;
                    }
                    p{
                        color: #727272;
                        font-size: 15px;
                        font-family: $font1;
                        font-weight: 400;
                        line-height: 26px;
                    }
                }
            }
        }
    }
}